ghcid-ng is a ghci-based file watcher and recompiler for Haskell projects, leveraging
Haskell’s interpreted mode for faster reloads.
ghcid-ng watches your modules for changes and reloads them in a ghci session, displaying
any errors.
Note that the ghcid-ng Rust library is a convenience and shouldn’t be depended on. I do not
consider this to be a public/stable API and will make breaking changes here in minor version
bumps. If you’d like a stable ghcid-ng Rust API for some reason, let me know and we can maybe
work something out.
Modules
- cli
- Command-line argument parser and argument access.
Structs
- Ghci
- A
ghcisession. - Ghci
Opts - Options for constructing a
Ghci. This is like a lower-effort builder interface, mostly provided because Rust tragically lacks named arguments. - Tracing
Opts - Options for initializing the
tracinglogging framework. This is like a lower-effort builder interface, mostly provided because Rust tragically lacks named arguments. - Watcher
- A
watchexecwatcher which waits for file changes and sends reload events to the containedghcisession. - Watcher
Opts - Options for constructing a
Watcher. This is like a lower-effort builder interface, mostly provided because Rust tragically lacks named arguments.